@@ -10,7 +10,7 @@ from .converters import QuaternionConvertersMixin
 
 
 def QuaternionicArray(jit=jit, dtype=float):
-    """Construct a quaternionic array type
+    """Construct a quaternionic array type.
 
     This factory returns a `class` encapsulating a quaternionic array type,
     where the jit function and dtype are passed to this factory function, and
@@ -22,7 +22,7 @@ def QuaternionicArray(jit=jit, dtype=float):
 
     """
     class QArray(QuaternionPropertiesMixin(jit), QuaternionConvertersMixin(jit), np.ndarray):
-        """Subclass of numpy arrays interpreted as quaternions
+        """Subclass of numpy arrays interpreted as quaternions.
 
         This class encapsulates quaternion algebra, with numpy's "ufunc"s
         overridden by quaternionic methods.  Standard algebraic operations can be
@@ -30,11 +30,11 @@ def QuaternionicArray(jit=jit, dtype=float):
         also be used as expected — as in `np.exp(q)`, `np.log(q)`, etc.
 
         Because this is a subclass of numpy's ndarray object, its constructor takes
-        anything the ndarray constructor takes, or just an ndarray to be considered
+        anything the ndarray constructor takes, or just an ndarray to be re-interpreted
         as a quaternion array:
 
             q1 = quaternionic.array([1, 2, 3, 4])  # explicit array
-            q2 = quaternionic.array(np.random.rand(10, 4))  # re-interpret ndarray
+            q2 = quaternionic.array(np.random.normal(size=(10, 4))  # re-interpret ndarray
 
         In addition to the basic numpy array features, we also have a number of
         extra properties that are particularly useful for quaternions, including
@@ -104,6 +104,13 @@ def QuaternionicArray(jit=jit, dtype=float):
                     "arrays of individual components, and `q.vector` to return the \"vector\" part."
                 )
 
+        def __array_function__(self, func, types, args, kwargs):
+            output = super().__array_function__(func, types, args, kwargs)
+            if func in [np.ones_like]:
+                # Want the last dimension to equal [1,0,0,0] not [1,1,1,1]
+                output.vector = 0
+            return output
+
         def __array_ufunc__(self, ufunc, method, *args, **kwargs):
             from . import algebra_ufuncs as algebra
 
@@ -169,6 +176,7 @@ def QuaternionicArray(jit=jit, dtype=float):
             elif ufunc in [
                 np.negative, np.positive, np.conj, np.conjugate, np.invert,
                 np.exp, np.log, np.sqrt, np.square, np.reciprocal,
+                np.core.umath._ones_like,
             ]:
                 if this_type(args[0]):
                     a1 = args[0]
@@ -183,7 +191,7 @@ def QuaternionicArray(jit=jit, dtype=float):
                     return NotImplemented
 
             # float64[4](float64[4], float64)
-            elif ufunc in [np.float_power]:
+            elif ufunc in [np.float_power, np.power]:
                 if this_type(args[0]) and not this_type(args[1]):
                     a1, a2 = args[:2]
                     b1 = a1.ndarray[..., 0]
